[jira] [Commented] (CB-14099) Cordova OSX - Apps not working with Plugins

2018-06-26 Thread ASF subversion and git services (JIRA)


[ 
https://issues.apache.org/jira/browse/CB-14099?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=16524575#comment-16524575
 ] 

ASF subversion and git services commented on CB-14099:
--

Commit 7bf9627f0135c6b3518292660b6e07e6f5815926 in cordova-common's branch 
refs/heads/master from エリス
[ https://gitbox.apache.org/repos/asf?p=cordova-common.git;h=7bf9627 ]

CB-14099 osx: Fixed Resolve Config Path for OSX

 This closes #32


> Cordova OSX - Apps not working with Plugins
> ---
>
> Key: CB-14099
> URL: https://issues.apache.org/jira/browse/CB-14099
> Project: Apache Cordova
>  Issue Type: Bug
>  Components: cordova-common, cordova-osx
> Environment: Cordova 8.0
> osx "El capitan"
>  
>Reporter: Jose Antonio Silva Korhonen
>Assignee: Tobias Bocanegra
>Priority: Major
> Fix For: Master
>
>
> It's not possible to get any app with any compatible plugins working on osx.
> 1 - Create a barebone Cordova App
>  * cordova create myapp org.apache.myapp myapp
> 2 - Add osx platform
>  * cordova platform add osx
> 3 - Add any plugin compatible with osx, for example cordova-plugin-file
>  * cordova plugin add cordova-plugin-file
> 4 - Run the App
>  * cordova run osx
> 5 - The App doesn't trigger "device ready"
>   The app stays on the state "CONNECTING TO DEVICE" for ever.
>   It's expect that is shown "DEVICE IS READY". If you remove all plugins from 
> the app then "DEVICE IS READY" is shown
>  
> On older versions of cordova osx this procedure worked.
>  



--
This message was sent by Atlassian JIRA
(v7.6.3#76005)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-14099) Cordova OSX - Apps not working with Plugins

2018-06-26 Thread ASF GitHub Bot (JIRA)


[ 
https://issues.apache.org/jira/browse/CB-14099?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=16524574#comment-16524574
 ] 

ASF GitHub Bot commented on CB-14099:
-

tripodsan closed pull request #32: CB-14099 osx: Fixed Resolve Config Path for 
OSX
URL: https://github.com/apache/cordova-common/pull/32
 
 
   

This is a PR merged from a forked repository.
As GitHub hides the original diff on merge, it is displayed below for
the sake of provenance:

As this is a foreign pull request (from a fork), the diff is supplied
below (as it won't show otherwise due to GitHub magic):

diff --git a/spec/ConfigChanges/ConfigFile.spec.js 
b/spec/ConfigChanges/ConfigFile.spec.js
index 98b1d98..c693420 100644
--- a/spec/ConfigChanges/ConfigFile.spec.js
+++ b/spec/ConfigChanges/ConfigFile.spec.js
@@ -72,6 +72,12 @@ describe('ConfigFile tests', function () {
 expect(configFile.resolveConfigFilePath('project_dir', 'ios', 
'config.xml')).toBe(configPath);
 });
 
+it('resolveConfigFilePath should return file path', function () {
+spyOn(configFile, 'getIOSProjectname').and.returnValue('osxpath');
+var configPath = path.join('project_dir', 'osxpath', 'config.xml');
+expect(configFile.resolveConfigFilePath('project_dir', 'osx', 
'config.xml')).toBe(configPath);
+});
+
 it('resolveConfigFilePath should return file path', function () {
 var configPath = path.join('project_dir', 'config.xml');
 expect(configFile.resolveConfigFilePath('project_dir', 'ubuntu', 
'config.xml')).toBe(configPath);
diff --git a/src/ConfigChanges/ConfigFile.js b/src/ConfigChanges/ConfigFile.js
index 0b2a23b..a42c06b 100644
--- a/src/ConfigChanges/ConfigFile.js
+++ b/src/ConfigChanges/ConfigFile.js
@@ -211,9 +211,12 @@ function resolveConfigFilePath (project_dir, platform, 
file) {
 if (file === 'config.xml') {
 if (platform === 'ubuntu') {
 filepath = path.join(project_dir, 'config.xml');
-} else if (platform === 'ios') {
-var iospath = module.exports.getIOSProjectname(project_dir);
-filepath = path.join(project_dir, iospath, 'config.xml');
+} else if (platform === 'ios' || platform === 'osx') {
+filepath = path.join(
+project_dir,
+module.exports.getIOSProjectname(project_dir),
+'config.xml'
+);
 } else {
 matches = modules.glob.sync(path.join(project_dir, '**', 
'config.xml'));
 if (matches.length) filepath = matches[0];
@@ -225,7 +228,7 @@ function resolveConfigFilePath (project_dir, platform, 
file) {
 return filepath;
 }
 
 // Find out the real name of an iOS project
 // TODO: glob is slow, need a better way or caching, or avoid using more than 
once.
 function getIOSProjectname (project_dir) {
@@ -225,7 +228,7 @@ function resolveConfigFilePath (project_dir, platform, 
 }
 
-// Find out the real name of an iOS project
+// Find out the real name of an iOS or OSX project
 // TODO: glob is slow, need a better way or caching, or avoid using more than 
once.
 var matches = modules.glob.sync(path.join(project_dir, '*.xcodeproj'));


 


This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
us...@infra.apache.org


> Cordova OSX - Apps not working with Plugins
> ---
>
> Key: CB-14099
> URL: https://issues.apache.org/jira/browse/CB-14099
> Project: Apache Cordova
>  Issue Type: Bug
>  Components: cordova-common, cordova-osx
> Environment: Cordova 8.0
> osx "El capitan"
>  
>Reporter: Jose Antonio Silva Korhonen
>Assignee: Tobias Bocanegra
>Priority: Major
> Fix For: Master
>
>
> It's not possible to get any app with any compatible plugins working on osx.
> 1 - Create a barebone Cordova App
>  * cordova create myapp org.apache.myapp myapp
> 2 - Add osx platform
>  * cordova platform add osx
> 3 - Add any plugin compatible with osx, for example cordova-plugin-file
>  * cordova plugin add cordova-plugin-file
> 4 - Run the App
>  * cordova run osx
> 5 - The App doesn't trigger "device ready"
>   The app stays on the state "CONNECTING TO DEVICE" for ever.
>   It's expect that is shown "DEVICE IS READY". If you remove all plugins from 
> the app then "DEVICE IS READY" is shown
>  
> On older versions of cordova osx this procedure worked.
>  



--
This message was sent by Atlassian JIRA
(v7.6.3#76005)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-14099) Cordova OSX - Apps not working with Plugins

2018-06-26 Thread Tobias Bocanegra (JIRA)


[ 
https://issues.apache.org/jira/browse/CB-14099?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=16524571#comment-16524571
 ] 

Tobias Bocanegra commented on CB-14099:
---

thanks [~erisu]. you're correct it fails for me, too.

with the fix of the PR, it works.

> Cordova OSX - Apps not working with Plugins
> ---
>
> Key: CB-14099
> URL: https://issues.apache.org/jira/browse/CB-14099
> Project: Apache Cordova
>  Issue Type: Bug
>  Components: cordova-osx
> Environment: Cordova 8.0
> osx "El capitan"
>  
>Reporter: Jose Antonio Silva Korhonen
>Assignee: Tobias Bocanegra
>Priority: Major
>
> It's not possible to get any app with any compatible plugins working on osx.
> 1 - Create a barebone Cordova App
>  * cordova create myapp org.apache.myapp myapp
> 2 - Add osx platform
>  * cordova platform add osx
> 3 - Add any plugin compatible with osx, for example cordova-plugin-file
>  * cordova plugin add cordova-plugin-file
> 4 - Run the App
>  * cordova run osx
> 5 - The App doesn't trigger "device ready"
>   The app stays on the state "CONNECTING TO DEVICE" for ever.
>   It's expect that is shown "DEVICE IS READY". If you remove all plugins from 
> the app then "DEVICE IS READY" is shown
>  
> On older versions of cordova osx this procedure worked.
>  



--
This message was sent by Atlassian JIRA
(v7.6.3#76005)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-14099) Cordova OSX - Apps not working with Plugins

2018-06-26 Thread ASF GitHub Bot (JIRA)


[ 
https://issues.apache.org/jira/browse/CB-14099?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=16524505#comment-16524505
 ] 

ASF GitHub Bot commented on CB-14099:
-

erisu commented on issue #32: CB-14099 osx: Fixed Resolve Config Path for OSX
URL: https://github.com/apache/cordova-common/pull/32#issuecomment-400528644
 
 
   @dpogue I was also thinking about that. Even when I saw the if condition for 
Ubuntu, I wanted to delete it because it had been deprecated, but also had to 
leave it because it was out-of-scope.
   
   If its a good idea, we could scope out some changes and code cleanup. I 
wouldn't mind working on it.


This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
us...@infra.apache.org


> Cordova OSX - Apps not working with Plugins
> ---
>
> Key: CB-14099
> URL: https://issues.apache.org/jira/browse/CB-14099
> Project: Apache Cordova
>  Issue Type: Bug
>  Components: cordova-osx
> Environment: Cordova 8.0
> osx "El capitan"
>  
>Reporter: Jose Antonio Silva Korhonen
>Assignee: Tobias Bocanegra
>Priority: Major
>
> It's not possible to get any app with any compatible plugins working on osx.
> 1 - Create a barebone Cordova App
>  * cordova create myapp org.apache.myapp myapp
> 2 - Add osx platform
>  * cordova platform add osx
> 3 - Add any plugin compatible with osx, for example cordova-plugin-file
>  * cordova plugin add cordova-plugin-file
> 4 - Run the App
>  * cordova run osx
> 5 - The App doesn't trigger "device ready"
>   The app stays on the state "CONNECTING TO DEVICE" for ever.
>   It's expect that is shown "DEVICE IS READY". If you remove all plugins from 
> the app then "DEVICE IS READY" is shown
>  
> On older versions of cordova osx this procedure worked.
>  



--
This message was sent by Atlassian JIRA
(v7.6.3#76005)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-14099) Cordova OSX - Apps not working with Plugins

2018-06-26 Thread Bryan Ellis (JIRA)


[ 
https://issues.apache.org/jira/browse/CB-14099?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=16524491#comment-16524491
 ] 

Bryan Ellis commented on CB-14099:
--

[~tripod]

I was able to reproduce the issue without the PR.

The first build always shows *Device is Ready* but the second, third, and so on 
will always show *Connecting to Device*

*My steps to reproduce (from PR)*
 - $ cordova create myapp org.apache.myapp myapp
 - $ cd myapp
 - $ cordova platform add osx
 - $ cordova plugin add cordova-plugin-file
 - $ cordova run osx
 ** This build will be show *Device is Ready*
 - $ cordova run osx
 ** This and any other builds there after will show *Connecting to Device.*

 

*My Environment*
{code}
$ system_profiler SPSoftwareDataType
Software:

System Software Overview:

System Version: macOS 10.13.6 (17G47b)
Kernel Version: Darwin 17.7.0
Boot Volume: Macintosh HD
Boot Mode: Normal
Secure Virtual Memory: Enabled
System Integrity Protection: Enabled 

$ cordova -v
8.0.0

$ cordova platform list
Installed platforms:
osx 4.0.1

$ node -v
v10.5.0

$ npm -v
6.1.0

$ xcodebuild -showsdks
macOS SDKs:
macOS 10.13 -sdk macosx10.13{code}

> Cordova OSX - Apps not working with Plugins
> ---
>
> Key: CB-14099
> URL: https://issues.apache.org/jira/browse/CB-14099
> Project: Apache Cordova
>  Issue Type: Bug
>  Components: cordova-osx
> Environment: Cordova 8.0
> osx "El capitan"
>  
>Reporter: Jose Antonio Silva Korhonen
>Assignee: Tobias Bocanegra
>Priority: Major
>
> It's not possible to get any app with any compatible plugins working on osx.
> 1 - Create a barebone Cordova App
>  * cordova create myapp org.apache.myapp myapp
> 2 - Add osx platform
>  * cordova platform add osx
> 3 - Add any plugin compatible with osx, for example cordova-plugin-file
>  * cordova plugin add cordova-plugin-file
> 4 - Run the App
>  * cordova run osx
> 5 - The App doesn't trigger "device ready"
>   The app stays on the state "CONNECTING TO DEVICE" for ever.
>   It's expect that is shown "DEVICE IS READY". If you remove all plugins from 
> the app then "DEVICE IS READY" is shown
>  
> On older versions of cordova osx this procedure worked.
>  



--
This message was sent by Atlassian JIRA
(v7.6.3#76005)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-14099) Cordova OSX - Apps not working with Plugins

2018-06-26 Thread Tobias Bocanegra (JIRA)


[ 
https://issues.apache.org/jira/browse/CB-14099?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=16524369#comment-16524369
 ] 

Tobias Bocanegra commented on CB-14099:
---

[~jask] I tested your steps above with and without the changes of 
https://github.com/apache/cordova-common/pull/32 and in both cases I couldn't 
reproduce your problems.

> Cordova OSX - Apps not working with Plugins
> ---
>
> Key: CB-14099
> URL: https://issues.apache.org/jira/browse/CB-14099
> Project: Apache Cordova
>  Issue Type: Bug
>  Components: cordova-osx
> Environment: Cordova 8.0
> osx "El capitan"
>  
>Reporter: Jose Antonio Silva Korhonen
>Assignee: Tobias Bocanegra
>Priority: Major
>
> It's not possible to get any app with any compatible plugins working on osx.
> 1 - Create a barebone Cordova App
>  * cordova create myapp org.apache.myapp myapp
> 2 - Add osx platform
>  * cordova platform add osx
> 3 - Add any plugin compatible with osx, for example cordova-plugin-file
>  * cordova plugin add cordova-plugin-file
> 4 - Run the App
>  * cordova run osx
> 5 - The App doesn't trigger "device ready"
>   The app stays on the state "CONNECTING TO DEVICE" for ever.
>   It's expect that is shown "DEVICE IS READY". If you remove all plugins from 
> the app then "DEVICE IS READY" is shown
>  
> On older versions of cordova osx this procedure worked.
>  



--
This message was sent by Atlassian JIRA
(v7.6.3#76005)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-14099) Cordova OSX - Apps not working with Plugins

2018-06-26 Thread ASF GitHub Bot (JIRA)


[ 
https://issues.apache.org/jira/browse/CB-14099?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=16524367#comment-16524367
 ] 

ASF GitHub Bot commented on CB-14099:
-

tripodsan commented on issue #32: CB-14099 osx: Fixed Resolve Config Path for 
OSX
URL: https://github.com/apache/cordova-common/pull/32#issuecomment-400502356
 
 
   +1


This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
us...@infra.apache.org


> Cordova OSX - Apps not working with Plugins
> ---
>
> Key: CB-14099
> URL: https://issues.apache.org/jira/browse/CB-14099
> Project: Apache Cordova
>  Issue Type: Bug
>  Components: cordova-osx
> Environment: Cordova 8.0
> osx "El capitan"
>  
>Reporter: Jose Antonio Silva Korhonen
>Assignee: Tobias Bocanegra
>Priority: Major
>
> It's not possible to get any app with any compatible plugins working on osx.
> 1 - Create a barebone Cordova App
>  * cordova create myapp org.apache.myapp myapp
> 2 - Add osx platform
>  * cordova platform add osx
> 3 - Add any plugin compatible with osx, for example cordova-plugin-file
>  * cordova plugin add cordova-plugin-file
> 4 - Run the App
>  * cordova run osx
> 5 - The App doesn't trigger "device ready"
>   The app stays on the state "CONNECTING TO DEVICE" for ever.
>   It's expect that is shown "DEVICE IS READY". If you remove all plugins from 
> the app then "DEVICE IS READY" is shown
>  
> On older versions of cordova osx this procedure worked.
>  



--
This message was sent by Atlassian JIRA
(v7.6.3#76005)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-14099) Cordova OSX - Apps not working with Plugins

2018-06-26 Thread ASF GitHub Bot (JIRA)


[ 
https://issues.apache.org/jira/browse/CB-14099?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=16523572#comment-16523572
 ] 

ASF GitHub Bot commented on CB-14099:
-

codecov-io edited a comment on issue #32: CB-14099 osx: Fixed Resolve Config 
Path for OSX
URL: https://github.com/apache/cordova-common/pull/32#issuecomment-400268353
 
 
   # 
[Codecov](https://codecov.io/gh/apache/cordova-common/pull/32?src=pr&el=h1) 
Report
   > Merging 
[#32](https://codecov.io/gh/apache/cordova-common/pull/32?src=pr&el=desc) into 
[master](https://codecov.io/gh/apache/cordova-common/commit/c10440111a9b471612d0a8679c1cd530ce7a0616?src=pr&el=desc)
 will **decrease** coverage by `<.01%`.
   > The diff coverage is `100%`.
   
   [![Impacted file tree 
graph](https://codecov.io/gh/apache/cordova-common/pull/32/graphs/tree.svg?height=150&width=650&src=pr&token=jsbcYRuqT5)](https://codecov.io/gh/apache/cordova-common/pull/32?src=pr&el=tree)
   
   ```diff
   @@Coverage Diff @@
   ##   master  #32  +/-   ##
   ==
   - Coverage   85.63%   85.62%   -0.01% 
   ==
 Files  19   19  
 Lines1747 1746   -1 
 Branches  367  367  
   ==
   - Hits 1496 1495   -1 
 Misses251  251
   ```
   
   
   | [Impacted 
Files](https://codecov.io/gh/apache/cordova-common/pull/32?src=pr&el=tree) | 
Coverage Δ | |
   |---|---|---|
   | 
[src/ConfigChanges/ConfigFile.js](https://codecov.io/gh/apache/cordova-common/pull/32/diff?src=pr&el=tree#diff-c3JjL0NvbmZpZ0NoYW5nZXMvQ29uZmlnRmlsZS5qcw==)
 | `89.78% <100%> (-0.08%)` | :arrow_down: |
   
   --
   
   [Continue to review full report at 
Codecov](https://codecov.io/gh/apache/cordova-common/pull/32?src=pr&el=continue).
   > **Legend** - [Click here to learn 
more](https://docs.codecov.io/docs/codecov-delta)
   > `Δ = absolute  (impact)`, `ø = not affected`, `? = missing data`
   > Powered by 
[Codecov](https://codecov.io/gh/apache/cordova-common/pull/32?src=pr&el=footer).
 Last update 
[c104401...6c0ca12](https://codecov.io/gh/apache/cordova-common/pull/32?src=pr&el=lastupdated).
 Read the [comment docs](https://docs.codecov.io/docs/pull-request-comments).
   


This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
us...@infra.apache.org


> Cordova OSX - Apps not working with Plugins
> ---
>
> Key: CB-14099
> URL: https://issues.apache.org/jira/browse/CB-14099
> Project: Apache Cordova
>  Issue Type: Bug
>  Components: cordova-osx
> Environment: Cordova 8.0
> osx "El capitan"
>  
>Reporter: Jose Antonio Silva Korhonen
>Assignee: Tobias Bocanegra
>Priority: Major
>
> It's not possible to get any app with any compatible plugins working on osx.
> 1 - Create a barebone Cordova App
>  * cordova create myapp org.apache.myapp myapp
> 2 - Add osx platform
>  * cordova platform add osx
> 3 - Add any plugin compatible with osx, for example cordova-plugin-file
>  * cordova plugin add cordova-plugin-file
> 4 - Run the App
>  * cordova run osx
> 5 - The App doesn't trigger "device ready"
>   The app stays on the state "CONNECTING TO DEVICE" for ever.
>   It's expect that is shown "DEVICE IS READY". If you remove all plugins from 
> the app then "DEVICE IS READY" is shown
>  
> On older versions of cordova osx this procedure worked.
>  



--
This message was sent by Atlassian JIRA
(v7.6.3#76005)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-14099) Cordova OSX - Apps not working with Plugins

2018-06-26 Thread ASF GitHub Bot (JIRA)


[ 
https://issues.apache.org/jira/browse/CB-14099?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=16523569#comment-16523569
 ] 

ASF GitHub Bot commented on CB-14099:
-

codecov-io edited a comment on issue #32: CB-14099 osx: Fixed Resolve Config 
Path for OSX
URL: https://github.com/apache/cordova-common/pull/32#issuecomment-400268353
 
 
   # 
[Codecov](https://codecov.io/gh/apache/cordova-common/pull/32?src=pr&el=h1) 
Report
   > Merging 
[#32](https://codecov.io/gh/apache/cordova-common/pull/32?src=pr&el=desc) into 
[master](https://codecov.io/gh/apache/cordova-common/commit/c10440111a9b471612d0a8679c1cd530ce7a0616?src=pr&el=desc)
 will **decrease** coverage by `<.01%`.
   > The diff coverage is `100%`.
   
   [![Impacted file tree 
graph](https://codecov.io/gh/apache/cordova-common/pull/32/graphs/tree.svg?width=650&src=pr&token=jsbcYRuqT5&height=150)](https://codecov.io/gh/apache/cordova-common/pull/32?src=pr&el=tree)
   
   ```diff
   @@Coverage Diff @@
   ##   master  #32  +/-   ##
   ==
   - Coverage   85.63%   85.62%   -0.01% 
   ==
 Files  19   19  
 Lines1747 1746   -1 
 Branches  367  367  
   ==
   - Hits 1496 1495   -1 
 Misses251  251
   ```
   
   
   | [Impacted 
Files](https://codecov.io/gh/apache/cordova-common/pull/32?src=pr&el=tree) | 
Coverage Δ | |
   |---|---|---|
   | 
[src/ConfigChanges/ConfigFile.js](https://codecov.io/gh/apache/cordova-common/pull/32/diff?src=pr&el=tree#diff-c3JjL0NvbmZpZ0NoYW5nZXMvQ29uZmlnRmlsZS5qcw==)
 | `89.78% <100%> (-0.08%)` | :arrow_down: |
   
   --
   
   [Continue to review full report at 
Codecov](https://codecov.io/gh/apache/cordova-common/pull/32?src=pr&el=continue).
   > **Legend** - [Click here to learn 
more](https://docs.codecov.io/docs/codecov-delta)
   > `Δ = absolute  (impact)`, `ø = not affected`, `? = missing data`
   > Powered by 
[Codecov](https://codecov.io/gh/apache/cordova-common/pull/32?src=pr&el=footer).
 Last update 
[c104401...6c0ca12](https://codecov.io/gh/apache/cordova-common/pull/32?src=pr&el=lastupdated).
 Read the [comment docs](https://docs.codecov.io/docs/pull-request-comments).
   


This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
us...@infra.apache.org


> Cordova OSX - Apps not working with Plugins
> ---
>
> Key: CB-14099
> URL: https://issues.apache.org/jira/browse/CB-14099
> Project: Apache Cordova
>  Issue Type: Bug
>  Components: cordova-osx
> Environment: Cordova 8.0
> osx "El capitan"
>  
>Reporter: Jose Antonio Silva Korhonen
>Assignee: Tobias Bocanegra
>Priority: Major
>
> It's not possible to get any app with any compatible plugins working on osx.
> 1 - Create a barebone Cordova App
>  * cordova create myapp org.apache.myapp myapp
> 2 - Add osx platform
>  * cordova platform add osx
> 3 - Add any plugin compatible with osx, for example cordova-plugin-file
>  * cordova plugin add cordova-plugin-file
> 4 - Run the App
>  * cordova run osx
> 5 - The App doesn't trigger "device ready"
>   The app stays on the state "CONNECTING TO DEVICE" for ever.
>   It's expect that is shown "DEVICE IS READY". If you remove all plugins from 
> the app then "DEVICE IS READY" is shown
>  
> On older versions of cordova osx this procedure worked.
>  



--
This message was sent by Atlassian JIRA
(v7.6.3#76005)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-14099) Cordova OSX - Apps not working with Plugins

2018-06-26 Thread ASF GitHub Bot (JIRA)


[ 
https://issues.apache.org/jira/browse/CB-14099?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=16523568#comment-16523568
 ] 

ASF GitHub Bot commented on CB-14099:
-

codecov-io commented on issue #32: CB-14099 osx: Fixed Resolve Config Path for 
OSX
URL: https://github.com/apache/cordova-common/pull/32#issuecomment-400268353
 
 
   # 
[Codecov](https://codecov.io/gh/apache/cordova-common/pull/32?src=pr&el=h1) 
Report
   > Merging 
[#32](https://codecov.io/gh/apache/cordova-common/pull/32?src=pr&el=desc) into 
[master](https://codecov.io/gh/apache/cordova-common/commit/c10440111a9b471612d0a8679c1cd530ce7a0616?src=pr&el=desc)
 will **decrease** coverage by `<.01%`.
   > The diff coverage is `100%`.
   
   [![Impacted file tree 
graph](https://codecov.io/gh/apache/cordova-common/pull/32/graphs/tree.svg?token=jsbcYRuqT5&src=pr&height=150&width=650)](https://codecov.io/gh/apache/cordova-common/pull/32?src=pr&el=tree)
   
   ```diff
   @@Coverage Diff @@
   ##   master  #32  +/-   ##
   ==
   - Coverage   85.63%   85.62%   -0.01% 
   ==
 Files  19   19  
 Lines1747 1746   -1 
 Branches  367  367  
   ==
   - Hits 1496 1495   -1 
 Misses251  251
   ```
   
   
   | [Impacted 
Files](https://codecov.io/gh/apache/cordova-common/pull/32?src=pr&el=tree) | 
Coverage Δ | |
   |---|---|---|
   | 
[src/ConfigChanges/ConfigFile.js](https://codecov.io/gh/apache/cordova-common/pull/32/diff?src=pr&el=tree#diff-c3JjL0NvbmZpZ0NoYW5nZXMvQ29uZmlnRmlsZS5qcw==)
 | `89.78% <100%> (-0.08%)` | :arrow_down: |
   
   --
   
   [Continue to review full report at 
Codecov](https://codecov.io/gh/apache/cordova-common/pull/32?src=pr&el=continue).
   > **Legend** - [Click here to learn 
more](https://docs.codecov.io/docs/codecov-delta)
   > `Δ = absolute  (impact)`, `ø = not affected`, `? = missing data`
   > Powered by 
[Codecov](https://codecov.io/gh/apache/cordova-common/pull/32?src=pr&el=footer).
 Last update 
[c104401...6c0ca12](https://codecov.io/gh/apache/cordova-common/pull/32?src=pr&el=lastupdated).
 Read the [comment docs](https://docs.codecov.io/docs/pull-request-comments).
   


This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
us...@infra.apache.org


> Cordova OSX - Apps not working with Plugins
> ---
>
> Key: CB-14099
> URL: https://issues.apache.org/jira/browse/CB-14099
> Project: Apache Cordova
>  Issue Type: Bug
>  Components: cordova-osx
> Environment: Cordova 8.0
> osx "El capitan"
>  
>Reporter: Jose Antonio Silva Korhonen
>Assignee: Tobias Bocanegra
>Priority: Major
>
> It's not possible to get any app with any compatible plugins working on osx.
> 1 - Create a barebone Cordova App
>  * cordova create myapp org.apache.myapp myapp
> 2 - Add osx platform
>  * cordova platform add osx
> 3 - Add any plugin compatible with osx, for example cordova-plugin-file
>  * cordova plugin add cordova-plugin-file
> 4 - Run the App
>  * cordova run osx
> 5 - The App doesn't trigger "device ready"
>   The app stays on the state "CONNECTING TO DEVICE" for ever.
>   It's expect that is shown "DEVICE IS READY". If you remove all plugins from 
> the app then "DEVICE IS READY" is shown
>  
> On older versions of cordova osx this procedure worked.
>  



--
This message was sent by Atlassian JIRA
(v7.6.3#76005)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-14099) Cordova OSX - Apps not working with Plugins

2018-06-26 Thread ASF GitHub Bot (JIRA)


[ 
https://issues.apache.org/jira/browse/CB-14099?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=16523541#comment-16523541
 ] 

ASF GitHub Bot commented on CB-14099:
-

erisu opened a new pull request #32: CB-14099 osx: Fixed Resolve Config Path 
for OSX
URL: https://github.com/apache/cordova-common/pull/32
 
 
   ### Platforms affected
   OSX
   
   ### What does this PR do?
   Updates the Resolve Config Path for OSX.
   
   I have identified that the initial build was successful but the consecutive 
builds fail because it updated the incorrect `config.xml` file.
   
   I was able to narrow down this issue coming from the `resolveConfigFilePath` 
method. This method currently handles special cases for Android, Ubuntu, and 
iOS. For all other platforms, it would fall back to glob for the config.xml. 
This is what was happens for OSX.
   
   When building for the first time, you have installed a fresh copy of the OSX 
platform. 
   At this time, when globbing, it will find the correct config.xml file 
located in `/.tests//platforms/osx//config.xml`.
   
   In the consecutive build, when globbing, it finds and updates the incorrect 
config.xml file. The file it finds is: 
`/.tests/osx//platforms/osx/build/.app/Contents/Resources/config.xml`
   This is because of the folder/file order structure and globbing nature. 
Since this file was created after the first build (build history), it happens 
to find this file first.
   
   ### What testing has been done on this change?
   - https://travis-ci.org/erisu/cordova-common/builds/396805720
   
   I also followed the reported issue steps:
   - $ cordova create myapp org.apache.myapp myapp
   - $ cordova platform add osx
 - I used a cloned version of `cordova-osx@master` with modified 
`package.json` to use `cordova-common#CB-14099` with my fix.
   - $ cordova plugin add cordova-plugin-file
   - $ cordova run osx
 - I ran this step 3x times.
   
   ### Checklist
   - [x] [Reported an issue](http://cordova.apache.org/contribute/issues.html) 
in the JIRA database
   - [x] Commit message follows the format: "CB-3232: (android) Fix bug with 
resolving file paths", where CB- is the JIRA ID & "android" is the platform 
affected.
   - [x] Added automated test coverage as appropriate for this change.
   


This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
us...@infra.apache.org


> Cordova OSX - Apps not working with Plugins
> ---
>
> Key: CB-14099
> URL: https://issues.apache.org/jira/browse/CB-14099
> Project: Apache Cordova
>  Issue Type: Bug
>  Components: cordova-osx
> Environment: Cordova 8.0
> osx "El capitan"
>  
>Reporter: Jose Antonio Silva Korhonen
>Assignee: Tobias Bocanegra
>Priority: Major
>
> It's not possible to get any app with any compatible plugins working on osx.
> 1 - Create a barebone Cordova App
>  * cordova create myapp org.apache.myapp myapp
> 2 - Add osx platform
>  * cordova platform add osx
> 3 - Add any plugin compatible with osx, for example cordova-plugin-file
>  * cordova plugin add cordova-plugin-file
> 4 - Run the App
>  * cordova run osx
> 5 - The App doesn't trigger "device ready"
>   The app stays on the state "CONNECTING TO DEVICE" for ever.
>   It's expect that is shown "DEVICE IS READY". If you remove all plugins from 
> the app then "DEVICE IS READY" is shown
>  
> On older versions of cordova osx this procedure worked.
>  



--
This message was sent by Atlassian JIRA
(v7.6.3#76005)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org



[jira] [Commented] (CB-14099) Cordova OSX - Apps not working with Plugins

2018-05-19 Thread Jose Antonio Silva Korhonen (JIRA)

[ 
https://issues.apache.org/jira/browse/CB-14099?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=16481618#comment-16481618
 ] 

Jose Antonio Silva Korhonen commented on CB-14099:
--

Hi [~tripod]

It seems a general issue with +any+ plugin for osx. Are you able to have an OSX 
App with any compatible plugin running getting to "device ready"-state ?

Can you take a look please?

Thanks

 

> Cordova OSX - Apps not working with Plugins
> ---
>
> Key: CB-14099
> URL: https://issues.apache.org/jira/browse/CB-14099
> Project: Apache Cordova
>  Issue Type: Bug
>  Components: cordova-osx
> Environment: Cordova 6
> osx "El capitan"
>  
>Reporter: Jose Antonio Silva Korhonen
>Assignee: Tobias Bocanegra
>Priority: Major
>
> It's not possible to get any app with any compatible plugins working on osx.
> 1 - Create a barebone Cordova App
>  * cordova create myapp org.apache.myapp myapp
> 2 - Add osx platform
>  * cordova platform add osx
> 3 - Add any plugin compatible with osx, for example cordova-plugin-file
>  * cordova plugin add cordova-plugin-file
> 4 - Run the App
>  * cordova run osx
> 5 - The App doesn't trigger "device ready"
>   The app stays on the state "CONNECTING TO DEVICE" for ever.
>   It's expect that is shown "DEVICE IS READY". If you remove all plugins from 
> the app then "DEVICE IS READY" is shown
>  
> On older versions of cordova osx this procedure worked.
>  



--
This message was sent by Atlassian JIRA
(v7.6.3#76005)

-
To unsubscribe, e-mail: issues-unsubscr...@cordova.apache.org
For additional commands, e-mail: issues-h...@cordova.apache.org